pm4py.streaming.algo.discovery package
======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.streaming.algo.discovery.dfg

Module contents
---------------

.. automodule:: pm4py.streaming.algo.discovery
   :members:
   :undoc-members:
   :show-inheritance:
